==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/FinalValueLayerDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnnotationLayerDescription } from "./AnnotationLayerDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var FinalValueLayerDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FinalValueLayerDescription, _super);
    function FinalValueLayerDescription() {
        var _this = _super.call(this) || this;
        _this.dx = null;
        _this.dy = null;
        _this.dw = null;
        _this.dv = null;
        _this.dt = null;
        _this.de = 0;
        _this.dr = 0;
        _this.du = null;
        _this.dg = 0;
        _this.di = 0;
        _this.dh = 0;
        _this.df = 0;
        _this.dj = 0;
        return _this;
    }
    FinalValueLayerDescription.prototype.get_type = function () {
        return "FinalValueLayer";
    };
    Object.defineProperty(FinalValueLayerDescription.prototype, "targetSeriesName", {
        get: function () {
            return this.dx;
        },
        set: function (a) {
            this.dx = a;
            this.e("TargetSeriesName");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "targetSeriesRef", {
        get: function () {
            return this.dy;
        },
        set: function (a) {
            this.dy = a;
            this.e("TargetSeriesRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "finalValueSelectionMode", {
        get: function () {
            return this.dw;
        },
        set: function (a) {
            this.dw = a;
            this.e("FinalValueSelectionMode");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationTextColor", {
        get: function () {
            return this.dv;
        },
        set: function (a) {
            this.dv = a;
            this.e("AxisAnnotationTextColor");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationBackground", {
        get: function () {
            return this.dt;
        },
        set: function (a) {
            this.dt = a;
            this.e("AxisAnnotationBackground");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationBackgroundCornerRadius", {
        get: function () {
            return this.de;
        },
        set: function (a) {
            this.de = a;
            this.e("AxisAnnotationBackgroundCornerRadius");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationInterpolatedValuePrecision", {
        get: function () {
            return this.dr;
        },
        set: function (a) {
            this.dr = a;
            this.e("AxisAnnotationInterpolatedValuePrecision");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationOutline", {
        get: function () {
            return this.du;
        },
        set: function (a) {
            this.du = a;
            this.e("AxisAnnotationOutline");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationPaddingLeft", {
        get: function () {
            return this.dg;
        },
        set: function (a) {
            this.dg = a;
            this.e("AxisAnnotationPaddingLeft");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationPaddingTop", {
        get: function () {
            return this.di;
        },
        set: function (a) {
            this.di = a;
            this.e("AxisAnnotationPaddingTop");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationPaddingRight", {
        get: function () {
            return this.dh;
        },
        set: function (a) {
            this.dh = a;
            this.e("AxisAnnotationPaddingRight");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationPaddingBottom", {
        get: function () {
            return this.df;
        },
        set: function (a) {
            this.df = a;
            this.e("AxisAnnotationPaddingBottom");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationStrokeThickness", {
        get: function () {
            return this.dj;
        },
        set: function (a) {
            this.dj = a;
            this.e("AxisAnnotationStrokeThickness");
        },
        enumerable: false,
        configurable: true
    });
    FinalValueLayerDescription.$t = markType(FinalValueLayerDescription, 'FinalValueLayerDescription', AnnotationLayerDescription.$);
    return FinalValueLayerDescription;
}(AnnotationLayerDescription));
export { FinalValueLayerDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/FinalValueLayerDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnnotationLayerDescription } from "./AnnotationLayerDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var FinalValueLayerDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FinalValueLayerDescription, _super);
    function FinalValueLayerDescription() {
        var _this = _super.call(this) || this;
        _this.gy = null;
        _this.gz = null;
        _this.gx = null;
        _this.gw = null;
        _this.gt = null;
        _this.gf = 0;
        _this.gr = 0;
        _this.gv = null;
        _this.gh = 0;
        _this.gj = 0;
        _this.gi = 0;
        _this.gg = 0;
        _this.gk = 0;
        _this.gu = null;
        return _this;
    }
    FinalValueLayerDescription.prototype.get_type = function () {
        return "FinalValueLayer";
    };
    Object.defineProperty(FinalValueLayerDescription.prototype, "targetSeriesName", {
        get: function () {
            return this.gy;
        },
        set: function (a) {
            this.gy = a;
            this.g("TargetSeriesName");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "targetSeriesRef", {
        get: function () {
            return this.gz;
        },
        set: function (a) {
            this.gz = a;
            this.g("TargetSeriesRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "finalValueSelectionMode", {
        get: function () {
            return this.gx;
        },
        set: function (a) {
            this.gx = a;
            this.g("FinalValueSelectionMode");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationTextColor", {
        get: function () {
            return this.gw;
        },
        set: function (a) {
            this.gw = a;
            this.g("AxisAnnotationTextColor");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationBackground", {
        get: function () {
            return this.gt;
        },
        set: function (a) {
            this.gt = a;
            this.g("AxisAnnotationBackground");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationBackgroundCornerRadius", {
        get: function () {
            return this.gf;
        },
        set: function (a) {
            this.gf = a;
            this.g("AxisAnnotationBackgroundCornerRadius");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationInterpolatedValuePrecision", {
        get: function () {
            return this.gr;
        },
        set: function (a) {
            this.gr = a;
            this.g("AxisAnnotationInterpolatedValuePrecision");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationOutline", {
        get: function () {
            return this.gv;
        },
        set: function (a) {
            this.gv = a;
            this.g("AxisAnnotationOutline");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationPaddingLeft", {
        get: function () {
            return this.gh;
        },
        set: function (a) {
            this.gh = a;
            this.g("AxisAnnotationPaddingLeft");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationPaddingTop", {
        get: function () {
            return this.gj;
        },
        set: function (a) {
            this.gj = a;
            this.g("AxisAnnotationPaddingTop");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationPaddingRight", {
        get: function () {
            return this.gi;
        },
        set: function (a) {
            this.gi = a;
            this.g("AxisAnnotationPaddingRight");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationPaddingBottom", {
        get: function () {
            return this.gg;
        },
        set: function (a) {
            this.gg = a;
            this.g("AxisAnnotationPaddingBottom");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationStrokeThickness", {
        get: function () {
            return this.gk;
        },
        set: function (a) {
            this.gk = a;
            this.g("AxisAnnotationStrokeThickness");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FinalValueLayerDescription.prototype, "axisAnnotationFormatLabelRef", {
        get: function () {
            return this.gu;
        },
        set: function (a) {
            this.gu = a;
            this.g("AxisAnnotationFormatLabelRef");
        },
        enumerable: false,
        configurable: true
    });
    FinalValueLayerDescription.$t = markType(FinalValueLayerDescription, 'FinalValueLayerDescription', AnnotationLayerDescription.$);
    return FinalValueLayerDescription;
}(AnnotationLayerDescription));
export { FinalValueLayerDescription };
